﻿using Microsoft.AspNetCore.Mvc;
using WebApiEntityFrameworkMediatr.Data;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;

namespace WebApiEntityFrameworkMediatr.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class ProductsController : ControllerBase
    {
        private readonly SalesContext _salesContext;

        public ProductsController (SalesContext salesContext)
        {
            _salesContext = salesContext;
        }

        [HttpGet]
        public ActionResult Get(int take = 10, int skip = 0)
        {
            return Ok(_salesContext.Products.OrderBy(p => p.ProductId).Skip(skip).Take(take));
        }
        
        [HttpGet("{productId}")]
        public async Task<ActionResult> Get(int productId)
        {
            return Ok(await _salesContext.Products.FirstOrDefaultAsync(p => p.ProductId == productId));
        }
        
        [HttpPost]
        public async Task<ActionResult> Post(Product product)
        {
            _salesContext.Products.Add(product);
            await _salesContext.SaveChangesAsync();
            return Ok(product);
        }
        
        [HttpPut("{productId}")]
        public async Task<IActionResult> PutProduct(int productId, Product product)
        {
            if (productId != product.ProductId)
            {
                return BadRequest();
            }

            _salesContext.Entry(product).State = EntityState.Modified;

            await _salesContext.SaveChangesAsync();

            return NoContent();
        }
    }
}
