﻿using MediatR;
using Microsoft.EntityFrameworkCore;
using WebApiEntityFrameworkMediatr.EventHandlers;

namespace WebApiEntityFrameworkMediatr.Data
{
    public class SalesContext : DbContext
    {
        private readonly IMediator _mediator;

        public SalesContext(DbContextOptions<SalesContext> options, IMediator mediator) : base(options)
        {
            _mediator = mediator;
        }

        public DbSet<Product>? Products { get; set; }
        
        public override async Task<int> SaveChangesAsync(CancellationToken cancellationToken = default)
        {
            var resultOfSave = await base.SaveChangesAsync(cancellationToken);
            
            var products = ChangeTracker.Entries().Where(ee => ee.Entity is Product).Select(ee => ee.Entity as Product);
            foreach (var product in products)
            {
                await _mediator.Publish(new ProductNotification(product));
            }
            return resultOfSave;
        }
    }
}